@@ -336,7 +336,7 @@ boolean MapPY(FcitxPinyinConfig* pyconfig, const char* strPYorigin, char strMap[
 
     size_t          len = strlen(strPY);
 
-    if (pyconfig->bMisstypeNGGN && strPY[len - 1] == 'n' && strPY[len - 2] == 'g') {
+    if (pyconfig->bMisstypeNGGN && len > 2 && strPY[len - 1] == 'n' && strPY[len - 2] == 'g') {
         strPY[len - 2] = 'n';
         strPY[len - 1] = 'g';
     }
@@ -446,7 +446,11 @@ boolean MapToPY(char strMap[3], char *strPY)
  * 0表示相等
  * b指示是声母还是韵母，true表示声母
  */
-int Cmp1Map(FcitxPinyinConfig* pyconfig, char map1, char map2, boolean b, boolean bUseMH, boolean bSP)
+int Cmp1Map(FcitxPinyinConfig* pyconfig,
+            char map1, char map2,
+            boolean is_S,
+            boolean bUseMH,
+            boolean bSP)
 {
     int             iVal;
 
@@ -457,10 +461,14 @@ int Cmp1Map(FcitxPinyinConfig* pyconfig, char map1, char map2, boolean b, boolea
         if (map1 == map2)
             return 0;
 
-        if (b) {
+        if (is_S) {
             iVal = GetMHIndex_S2(pyconfig->MHPY_S, map1, map2, bUseMH);
         } else {
             iVal = GetMHIndex_C2(pyconfig->MHPY_C, map1, map2);
+            // check V U only for j,q,x
+            if (!bUseMH && iVal == 6) {
+                iVal = -1;
+            }
         }
 
         if (iVal >= 0)
@@ -488,7 +496,7 @@ int Cmp2Map(FcitxPinyinConfig* pyconfig, char map1[3], char map2[3], boolean bSP
     if (i)
         return i;
 
-    return Cmp1Map(pyconfig, map1[1], map2[1], false, false, bSP);
+    return Cmp1Map(pyconfig, map1[1], map2[1], false, IsJ_Q_X_Y(map2[0]), bSP);
 }
 
 /*
@@ -505,13 +513,15 @@ int CmpMap(FcitxPinyinConfig* pyconfig, const char *strMap1,
     *iMatchedLength = 0;
 
     for (;;) {
-        if (!strMap2[*iMatchedLength])
+        if (!strMap2[*iMatchedLength]) {
             return (strMap1[*iMatchedLength] - strMap2[*iMatchedLength]);
+        }
 
-        if (((*iMatchedLength + 1) % 2) && (IsZ_C_S(strMap2[*iMatchedLength]) && (strMap2[*iMatchedLength + 1] == '0' || !strMap2[*iMatchedLength + 1])))
+        if (((*iMatchedLength + 1) % 2) && (IsZ_C_S(strMap2[*iMatchedLength]) && (strMap2[*iMatchedLength + 1] == '0' || !strMap2[*iMatchedLength + 1]))) {
             val = Cmp1Map(pyconfig, strMap1[*iMatchedLength], strMap2[*iMatchedLength], (*iMatchedLength + 1) % 2, true, bSP);
-        else
+        } else {
             val = Cmp1Map(pyconfig, strMap1[*iMatchedLength], strMap2[*iMatchedLength], (*iMatchedLength + 1) % 2, false, bSP);
+        }
 
         if (val)
             return val;
