@@ -56,7 +56,7 @@ void FcitxModuleLoad(FcitxInstance* instance)
                 if (!fp)
                     break;
                 fclose(fp);
-                handle = dlopen(modulePath, RTLD_NOW | RTLD_GLOBAL);
+                handle = dlopen(modulePath, RTLD_NOW | RTLD_NODELETE | (addon->loadLocal ? RTLD_LOCAL : RTLD_GLOBAL));
                 if (!handle) {
                     FcitxLog(ERROR, _("Module: open %s fail %s") , modulePath , dlerror());
                     break;
