@@ -40,6 +40,7 @@
 #ifdef ENABLE_OPENCC
 #include "chttrans-opencc.h"
 #endif
+#include "module/freedesktop-notify/fcitx-freedesktop-notify.h"
 
 #define TABLE_GBKS2T "gbks2t.tab"
 
@@ -161,30 +162,41 @@ void *ChttransCreate(FcitxInstance* instance)
 
 INPUT_RETURN_VALUE HotkeyToggleChttransState(void* arg)
 {
-    FcitxChttrans* transState = (FcitxChttrans*) arg;
+    FcitxChttrans *transState = (FcitxChttrans*)arg;
+    FcitxInstance *instance = transState->owner;
 
-    FcitxUIStatus *status = FcitxUIGetStatusByName(transState->owner, "chttrans");
+    FcitxUIStatus *status = FcitxUIGetStatusByName(instance, "chttrans");
     if (status->visible){
-        FcitxUIUpdateStatus(transState->owner, "chttrans");
+        FcitxUIUpdateStatus(instance, "chttrans");
+        boolean enabled = ChttransEnabled(transState);
+        FcitxFreeDesktopNotifyShowAddonTip(
+            instance, "fcitx-chttrans-toggle",
+            enabled ? "fcitx-chttrans-active" :
+                      "fcitx-chttrans-inactive",
+            _("Simplified Chinese To Traditional Chinese"),
+            enabled ? _("Traditional Chinese is enabled.") :
+                      _("Simplified Chinese is enabled."));
         return IRV_DO_NOTHING;
-    }
-    else
+    } else {
         return IRV_TO_PROCESS;
+    }
 }
 
 void ToggleChttransState(void* arg)
 {
-    FcitxChttrans* transState = (FcitxChttrans*) arg;
+    FcitxChttrans *transState = (FcitxChttrans*)arg;
+    FcitxInstance *instance = transState->owner;
     FcitxIM* im = FcitxInstanceGetCurrentIM(transState->owner);
     if (!im)
         return;
     boolean enabled = !ChttransEnabled(transState);
 
     fcitx_string_map_set(transState->enableIM, im->uniqueName, enabled);
-    FcitxUISetStatusString(transState->owner, "chttrans",
-                           enabled ? _("Traditional Chinese") :  _("Simplified Chinese"),
+    FcitxUISetStatusString(instance, "chttrans",
+                           enabled ? _("Traditional Chinese") :
+                           _("Simplified Chinese"),
                           _("Toggle Simp/Trad Chinese Conversion"));
-    FcitxUIUpdateInputWindow(transState->owner);
+    FcitxUIUpdateInputWindow(instance);
     SaveChttransConfig(transState);
 }
 
@@ -244,11 +256,12 @@ char *ConvertGBKSimple2Tradition(FcitxChttrans* transState, const char *strHZ)
     switch (transState->engine) {
     case ENGINE_OPENCC:
 #ifdef ENABLE_OPENCC
-        {
+        do {
             if (transState->ods2t == NULL) {
                 OpenCCInit(transState);
                 if (transState->ods2t == NULL) {
-                    return NULL;
+                    /* break to native as fallback */
+                    break;
                 }
             }
 
@@ -259,19 +272,17 @@ char *ConvertGBKSimple2Tradition(FcitxChttrans* transState, const char *strHZ)
             }
 
             return res;
-        }
+        } while(0);
 #endif
     case ENGINE_NATIVE: {
         FILE           *fp;
         char           *ret;
         int             i, len, ret_len;
-        char           *strBuf = NULL;
-        size_t          bufLen = 0;
         const char     *ps;
 
         if (!transState->s2t_table) {
-            len = 0;
-
+            char *strBuf = NULL;
+            size_t bufLen = 0;
             fp = FcitxXDGGetFileWithPrefix("data", TABLE_GBKS2T, "r", NULL);
             if (!fp) {
                 ret = (char *) malloc(sizeof(char) * (strlen(strHZ) + 1));
@@ -279,11 +290,17 @@ char *ConvertGBKSimple2Tradition(FcitxChttrans* transState, const char *strHZ)
                 return ret;
             }
             while (getline(&strBuf, &bufLen, fp) != -1) {
-                simple2trad_t *s2t;
+                simple2trad_t *s2t = NULL;
                 char *ps;
                 uint32_t wc;
 
                 ps = fcitx_utf8_get_char(strBuf, &wc);
+
+                HASH_FIND_INT(transState->s2t_table, &wc, s2t);
+                if (s2t) {
+                    continue;
+                }
+
                 s2t = (simple2trad_t*) malloc(sizeof(simple2trad_t));
                 s2t->wc = wc;
                 s2t->len = fcitx_utf8_char_len(ps);
@@ -292,8 +309,7 @@ char *ConvertGBKSimple2Tradition(FcitxChttrans* transState, const char *strHZ)
 
                 HASH_ADD_INT(transState->s2t_table, wc, s2t);
             }
-            if (strBuf)
-                free(strBuf);
+            fcitx_utils_free(strBuf);
         }
 
         i = 0;
@@ -344,34 +360,32 @@ char *ConvertGBKTradition2Simple(FcitxChttrans* transState, const char *strHZ)
     switch (transState->engine) {
     case ENGINE_OPENCC:
 #ifdef ENABLE_OPENCC
-        {
+        do {
             if (transState->odt2s == NULL) {
                 OpenCCInit(transState);
                 if (transState->odt2s == NULL) {
-                    return NULL;
+                    break;
                 }
             }
 
             char * res = OpenCCConvert(transState->odt2s, strHZ, (size_t) - 1);
 
-            if (res == (char *) - 1) {
+            if (!res || res == (char *) - 1) {
                 return NULL;
             }
 
             return res;
-        }
+        } while(0);
 #endif
     case ENGINE_NATIVE: {
         FILE           *fp;
         char           *ret;
         int             i, len, ret_len;
-        char           *strBuf = NULL;
-        size_t          bufLen = 0;
         const char     *ps;
 
         if (!transState->t2s_table) {
-            len = 0;
-
+            char *strBuf = NULL;
+            size_t bufLen = 0;
             fp = FcitxXDGGetFileWithPrefix("data", TABLE_GBKS2T, "r", NULL);
             if (!fp) {
                 ret = (char *) malloc(sizeof(char) * (strlen(strHZ) + 1));
@@ -379,11 +393,15 @@ char *ConvertGBKTradition2Simple(FcitxChttrans* transState, const char *strHZ)
                 return ret;
             }
             while (getline(&strBuf, &bufLen, fp) != -1) {
-                simple2trad_t *t2s;
+                simple2trad_t *t2s = NULL;
                 char *ps;
                 uint32_t wc;
 
                 ps = fcitx_utf8_get_char(strBuf, &wc);
+                HASH_FIND_INT(transState->s2t_table, &wc, t2s);
+                if (t2s) {
+                    continue;
+                }
                 t2s = (simple2trad_t*) malloc(sizeof(simple2trad_t));
 
                 fcitx_utf8_get_char(ps, &wc);
@@ -394,8 +412,7 @@ char *ConvertGBKTradition2Simple(FcitxChttrans* transState, const char *strHZ)
 
                 HASH_ADD_INT(transState->t2s_table, wc, t2s);
             }
-            if (strBuf)
-                free(strBuf);
+            fcitx_utils_free(strBuf);
         }
 
         i = 0;
@@ -438,11 +455,8 @@ boolean LoadChttransConfig(FcitxChttrans* transState)
         return false;
 
     FILE *fp;
-    char *file;
     fp = FcitxXDGGetFileUserWithPrefix("conf", "fcitx-chttrans.config",
-                                       "r", &file);
-    FcitxLog(DEBUG, "Load Config File %s", file);
-    free(file);
+                                       "r", NULL);
     if (!fp) {
         if (errno == ENOENT)
             SaveChttransConfig(transState);
@@ -464,12 +478,9 @@ CONFIG_DESC_DEFINE(GetChttransConfigDesc, "fcitx-chttrans.desc")
 void SaveChttransConfig(FcitxChttrans* transState)
 {
     FcitxConfigFileDesc* configDesc = GetChttransConfigDesc();
-    char *file;
     FILE *fp = FcitxXDGGetFileUserWithPrefix("conf", "fcitx-chttrans.config",
-                                             "w", &file);
-    FcitxLog(DEBUG, "Save Config to %s", file);
+                                             "w", NULL);
     FcitxConfigSaveConfigFileFp(fp, &transState->gconfig, configDesc);
-    free(file);
     if (fp) {
         fclose(fp);
     }
