@@ -28,14 +28,23 @@
 #include "fcitx/module.h"
 #include "im/keyboard/isocodes.h"
 
+#define GNOME_HELPER_NAME "org.fcitx.GnomeHelper"
+#define GNOME_HELPER_PATH "/org/fcitx/GnomeHelper"
+#define GNOME_HELPER_INTERFACE "org.fcitx.GnomeHelper"
+
 static void* FcitxXkbDBusCreate(struct _FcitxInstance* instance);
 static void FcitxXkbDBusDestroy(void* arg);
+static void FcitxXkbDBusHelperOwnerChanged(void* user_data, void* arg, const char* serviceName, const char* oldName, const char* newName);
+static void FcitxXkbDBusHelperServiceExistCallback(DBusPendingCall *call, void *data);
+DECLARE_ADDFUNCTIONS(XkbDBus)
 typedef struct _FcitxXkbDBus {
     FcitxInstance* owner;
     FcitxXkbRules* rules;
     FcitxIsoCodes* isocodes;
     DBusConnection* conn;
     DBusConnection* privconn;
+    int watcherId;
+    boolean hasHelper;
 } FcitxXkbDBus;
 
 FCITX_DEFINE_PLUGIN(fcitx_xkbdbus, module, FcitxModule) = {
@@ -120,8 +129,35 @@ void* FcitxXkbDBusCreate(FcitxInstance* instance)
         if (!rules)
             break;
 
+        int id = FcitxDBusWatchName(instance, "org.fcitx.GnomeHelper", xkbdbus,
+                                    FcitxXkbDBusHelperOwnerChanged, NULL, NULL);
+        if (id == 0) {
+            break;
+        }
+
+        xkbdbus->watcherId = id;
+
+        const char* helper = GNOME_HELPER_NAME;
+        DBusMessage* message = dbus_message_new_method_call(DBUS_SERVICE_DBUS, DBUS_PATH_DBUS, DBUS_INTERFACE_DBUS, "NameHasOwner");
+        dbus_message_append_args(message, DBUS_TYPE_STRING, &helper, DBUS_TYPE_INVALID);
+
+        DBusPendingCall* call = NULL;
+        dbus_bool_t reply =
+            dbus_connection_send_with_reply(xkbdbus->conn, message,
+                                            &call, DBUS_TIMEOUT_USE_DEFAULT);
+        if (reply == TRUE) {
+            dbus_pending_call_set_notify(call,
+                                         FcitxXkbDBusHelperServiceExistCallback,
+                                         xkbdbus,
+                                         NULL);
+            dbus_pending_call_unref(call);
+        }
+        dbus_connection_flush(xkbdbus->conn);
+        dbus_message_unref(message);
+
         xkbdbus->rules = rules;
         xkbdbus->isocodes = FcitxXkbReadIsoCodes(ISOCODES_ISO639_XML, ISOCODES_ISO3166_XML);
+        FcitxXkbDBusAddFunctions(instance);
         return xkbdbus;
     } while(0);
 
@@ -134,6 +170,10 @@ void FcitxXkbDBusDestroy(void* arg)
 {
     FcitxXkbDBus* xkbdbus = arg;
 
+    if (xkbdbus->watcherId) {
+        FcitxDBusUnwatchName(xkbdbus->owner, xkbdbus->watcherId);
+    }
+
     if (xkbdbus->conn) {
         dbus_connection_unregister_object_path(xkbdbus->conn, FCITX_XKB_PATH);
     }
@@ -286,3 +326,65 @@ DBusHandlerResult FcitxXkbDBusEventHandler (DBusConnection  *connection,
     }
     return result;
 }
+
+void FcitxXkbDBusHelperOwnerChanged(void* user_data, void* arg, const char* serviceName, const char* oldName, const char* newName) {
+    FCITX_UNUSED(oldName);
+    FcitxXkbDBus* xkbdbus = user_data;
+    /* old die and no new one */
+    if (strcmp(serviceName, GNOME_HELPER_NAME) == 0) {
+        if (strlen(newName) > 0) {
+            xkbdbus->hasHelper = true;
+        } else {
+            xkbdbus->hasHelper = false;
+        }
+    }
+}
+
+boolean FcitxXkbDBusLockGroupByHelper(FcitxXkbDBus *xkbdbus, int idx) {
+    DBusMessage* msg;
+    if (!xkbdbus->hasHelper) {
+        return false;
+    }
+    // create a signal and check for errors
+    msg = dbus_message_new_method_call(GNOME_HELPER_NAME,
+                                       GNOME_HELPER_PATH,
+                                       GNOME_HELPER_INTERFACE,
+                                       "LockXkbGroup");
+    do {
+        if (!msg) {
+            break;
+        }
+        if (!dbus_message_append_args(
+                msg,
+                DBUS_TYPE_INT32, &idx,
+                DBUS_TYPE_INVALID
+                )) {
+            break;
+        }
+        dbus_connection_send(xkbdbus->conn, msg, NULL);
+    } while(0);
+    return true;
+}
+
+
+void FcitxXkbDBusHelperServiceExistCallback(DBusPendingCall *call, void *data)
+{
+    FcitxXkbDBus* xkbdbus = (FcitxXkbDBus*) data;
+    DBusMessage *msg = dbus_pending_call_steal_reply(call);
+
+    if (msg) {
+        dbus_bool_t has = FALSE;
+        DBusError error;
+        dbus_error_init(&error);
+        dbus_message_get_args(msg, &error, DBUS_TYPE_BOOLEAN, &has,
+                              DBUS_TYPE_INVALID);
+        dbus_message_unref(msg);
+        if (!dbus_error_is_set(&error)) {
+            xkbdbus->hasHelper = has;
+        }
+        dbus_error_free(&error);
+    }
+}
+
+
+#include "fcitx-xkbdbus-addfunctions.h"
